@@ -1,5 +1,6 @@
 /**************************************************
-htmltemplate
+opengate server
+htmltemplate: module for inserting parameters to html template and seding out
 
 Copyright (C) 2005 Opengate Project Team
 Written by Katsuhiko Eguchi, 2005 
@@ -24,9 +25,10 @@ Email: watanaby@is.saga-u.ac.jp
 
 #include "opengatesrv.h"
 
-/*****************************************************/
-/* replace keywords(keys) in file(filename) and send out */
-/*****************************************************/
+/***********************************************************/
+/* replace keywords(keys) in file(filename) and send out   */
+/* keys[] has the pairs of pre and post string for replace */ 
+/***********************************************************/
 int htmlTemplate(char* filename, struct html_key* keys)
 {
   FILE *fp;
@@ -97,6 +99,7 @@ char* strSplit(char* str,const char* delimStr)
     return delimPoint;
 }
 
+/**********************************************************/
 /**********************************************************/
 int HtmlTemplate(char* filename, struct html_key* keys){
 
