@@ -212,7 +212,7 @@ int  main(int argc, char **argv)
   CreateCookie(cookie);
 
   /* set terminate signal handler */
-  if(Signal(SIGTERM, closeExit)==SIG_ERR){
+  if(signalx(SIGTERM, closeExit)==SIG_ERR){
     PutClientMsg("Error: Please contact the administrator(2)");    
     return 0;
   }
@@ -331,7 +331,7 @@ void closeExit(int signo)
   PutSessionEndToDb(cookie, mode[connectionMode]);
 
   /* signal is disabled */
-  Signal(SIGTERM, SIG_DFL);
+  signalx(SIGTERM, SIG_DFL);
 
   /* ignore redundant process */
   if(connectionMode!=DUPLICATED){
