@@ -218,7 +218,6 @@ int Pipe(int *fds);
 int Getpeername(int fd, struct sockaddr *sa, socklen_t *salenptr);
 int Socket(int family, int type, int protocol);
 int Listen(int fd, int backlog);
-Sigfunc * Signal(int signo, Sigfunc *func);
 void * Malloc(size_t size);
 
 char* getenvEx(char* env, int pre, int post);
@@ -252,3 +251,6 @@ void listAlarm(void);
 /* udp-client.c */
 int PutMacAddressToOpengateMd(char* macAddress);
 int PutDataToUdpPort(char* udpServerAddr, char* udpServerPort, char* buff);
+
+/* signal.c */
+Sigfunc* signalx(int signo, Sigfunc* func);
