@@ -35,15 +35,15 @@ int  main(int argc, char **argv)
   char clientAddr6[100]="::1";
   char userID[100]="user1";
   char language[100]="ja";
-  char extraID[100]="default";
+  char extraID[100]="";
   int duration=-60; 
   struct clientAddr ClientAddr;
   struct clientAddr *pClientAddr;
 
   pClientAddr = &ClientAddr;
-  strncpy(ClientAddr.ipAddr,"127.0.0.1",ADDRMAXLN);
+  strlcpy(ClientAddr.ipAddr,"127.0.0.1",ADDRMAXLN);
   ClientAddr.next=NULL;
-  strncpy(ClientAddr.ruleNumber,"10000",WORDMAXLN);
+  strlcpy(ClientAddr.ruleNumber,"10000",WORDMAXLN);
   ClientAddr.ipType=IPV4;
   ClientAddr.timeIn=time(NULL);
 
